Module fs_provider

Module fs_provider 

FileSystem-based implementations of typr-core traits

These implementations allow the CLI app to use the filesystem for reading sources and writing outputs.

Structs

FileSystemOutputHandler
Filesystem-based output handler for native compilation.
FileSystemSourceProvider
Filesystem-based source provider for native compilation.
NativePackageChecker
Native R package checker that can query R for package availability.