FileSystem-based implementations of typr-core traits
These implementations allow the CLI app to use the filesystem for reading sources and writing outputs.
Structs
- File
System Output Handler - Filesystem-based output handler for native compilation.
- File
System Source Provider - Filesystem-based source provider for native compilation.
- Native
Package Checker - Native R package checker that can query R for package availability.